<?php
// Класс события

namespace BotKit\Common;

class EventData {

	// Текст сообщения (если присутствует)
	private string $text;

	// Данные, которые были получены непосредственно сервером
	private $payload;

	// Тип события
	private int $event_type;

	// Тип обратного вызова (если событие - обратный вызов)
	private int $callback_type;

	// Данные обратного вызова (если событие - обратный вызов)
	private array $callback_data;

	public function __construct(
		$text,
		$payload,
		$event_type,
		$callback_type=CallbackType::None,
		$callback_data = []
	)
	{
		$this->text = $text;
		$this->payload = $payload;
		$this->event_type = $event_type;
		$this->callback_type = $callback_type;
		$this->callback_data = $callback_data;
	}

	// Возвращает объект $payload
	public function getPayload() {
		return $this->payload;
	}

	// Возвращает тип события
	public function getEventType() : int {
		return $this->event_type;
	}

	// Возвращает текст
	public function getText() : string {
		return $this->text;
	}

	// Сравнивает текст с параметром
	public function textIs(string $to_compare) : bool {
		return $to_compare == $this->text;
	}

	public function getCallbackType() : int {
		return $this->callback_type;
	}

	public function getCallbackData() {
		return $this->callback_data;
	}
	
}