<?php
// Класс пользователя бота

namespace BotKit\Common;

use BotKit\Enums\State;
use BotKit\Models\Model;

class User implements \ArrayAccess {
    
    private $platform_id;       // ID на платформе
    private State $state;       // Состояние
    private ?string $nick;      // Короткий идентификатор пользователя
    private array $dbobj;       // Модель из БД
    private bool $is_changed;   // Изменено ли состояние

    public function __construct(
        $platform_id,
        State $state,
        ?string $nick,
        array $dbobj
    )
    {
        $this->platform_id = $platform_id;
        $this->state = $state;
        $this->nick = $nick;
        $this->dbobj = $dbobj;
        $this->is_changed = false;
    }

    public function getPlatformID() {
        return $this->platform_id;
    }

    public function getNick() : ?string {
        return $this->nick;
    }

    public function getDbObject() : array {
        return $this->dbobj;
    }

    public function getState() : State {
        return $this->state;
    }

    public function hasChanged() : bool {
        return $this->is_changed;
    }

    // Устанавливает состояние
    // состояние будет отображаться в $this->state прежде чем пользователь
    // не будет сохранён
    public function setState(State $state) : void {
        $this->state = $state;
        $this['state'] = $state->value;
    }

    #region Реализация ArrayAccess
    public function offsetSet($offset, $value): void {
        $this->is_changed = true;
        if (is_null($offset)) {
            $this->dbobj[] = $value;
        } else {
            $this->dbobj[$offset] = $value;
        }
    }

    public function offsetExists($offset): bool {
        return isset($this->dbobj[$offset]);
    }

    public function offsetUnset($offset): void {
        unset($this->dbobj[$offset]);
    }

    public function offsetGet($offset) : mixed {
        return isset($this->dbobj[$offset]) ? $this->dbobj[$offset] : null;
    }
    #endregion
}